@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -73,7 +73,7 @@ class ArtifactRegistryTransport(abc.ABC):
 
         Args:
             host (Optional[str]):
-                 The hostname to connect to.
+                 The hostname to connect to (default: 'artifactregistry.googleapis.com').
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -136,6 +136,10 @@ class ArtifactRegistryTransport(abc.ABC):
             host += ":443"
         self._host = host
 
+    @property
+    def host(self):
+        return self._host
+
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -244,6 +248,11 @@ class ArtifactRegistryTransport(abc.ABC):
                 default_timeout=None,
                 client_info=client_info,
             ),
+            self.batch_delete_versions: gapic_v1.method.wrap_method(
+                self.batch_delete_versions,
+                default_timeout=None,
+                client_info=client_info,
+            ),
             self.list_files: gapic_v1.method.wrap_method(
                 self.list_files,
                 default_timeout=None,
@@ -532,6 +541,15 @@ class ArtifactRegistryTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def batch_delete_versions(
+        self,
+    ) -> Callable[
+        [version.BatchDeleteVersionsRequest],
+        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
+    ]:
+        raise NotImplementedError()
+
     @property
     def list_files(
         self,
