@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2022 Google LLC
+# Copyright 2023 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -32,6 +32,7 @@ __protobuf__ = proto.module(
         "ListVersionsResponse",
         "GetVersionRequest",
         "DeleteVersionRequest",
+        "BatchDeleteVersionsRequest",
         "BatchDeleteVersionsMetadata",
     },
 )
@@ -64,6 +65,7 @@ class Version(proto.Message):
     Attributes:
         name (str):
             The name of the version, for example:
+
             "projects/p1/locations/us-central1/repositories/repo1/packages/pkg1/versions/art1".
             If the package or version ID parts contain
             slashes, the slashes are escaped.
@@ -231,6 +233,36 @@ class DeleteVersionRequest(proto.Message):
     )
 
 
+class BatchDeleteVersionsRequest(proto.Message):
+    r"""The request to delete multiple versions across a repository.
+
+    Attributes:
+        parent (str):
+            The name of the repository holding all
+            requested versions.
+        names (MutableSequence[str]):
+            Required. The names of the versions to
+            delete. A maximum of 10000 versions can be
+            deleted in a batch.
+        validate_only (bool):
+            If true, the request is performed without
+            deleting data, following AIP-163.
+    """
+
+    parent: str = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    names: MutableSequence[str] = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    validate_only: bool = proto.Field(
+        proto.BOOL,
+        number=3,
+    )
+
+
 class BatchDeleteVersionsMetadata(proto.Message):
     r"""The metadata of an LRO from deleting multiple versions.
 
